@@ -1,5 +1,5 @@
 package MooseX::Role::WithOverloading::Meta::Role::Application::ToInstance;
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 
 # ABSTRACT: Roles which support overloading
@@ -7,12 +7,14 @@ our $VERSION = '0.02';
 use Moose::Role;
 use namespace::autoclean;
 
-with 'MooseX::Role::WithOverloading::Meta::Role::Application';
+with qw(
+    MooseX::Role::WithOverloading::Meta::Role::Application
+    MooseX::Role::WithOverloading::Meta::Role::Application::FixOverloadedRefs
+);
 
 1;
 
 __END__
-
 =pod
 
 =head1 NAME
@@ -21,12 +23,12 @@ MooseX::Role::WithOverloading::Meta::Role::Application::ToInstance - Roles which
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 AUTHORS
 
-  Florian Ragwitz <rafl@debian.org>
-  Tomas Doran <bobtfish@bobtfish.net>
+Florian Ragwitz <rafl@debian.org>
+Tomas Doran <bobtfish@bobtfish.net>
 
 =head1 COPYRIGHT AND LICENSE
 
@@ -35,6 +37,5 @@ This software is copyright (c) 2009 by Florian Ragwitz.
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
-=cut 
-
+=cut
 
